#  Licensed Materials - Property of IBM
#  5698-B34  Copyright IBM Corp. 2010
#  All rights reserved.
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
#    File: tivoli_eif/zOSEventSupport_rules.sh, OMNIbus, EventPump421
#    SID: 1.1
#    Date Modified: 10/09/16 10:41:12
#
#    Change History:
#    YY/MM/DD            Description
#    10/08/31            Initial IBM Tivoli Event Pump for z/OS V4.2.1
#                        Interim Feature 2
#
#  This script will copy IBM Tivoli Event Pump for z/OS V4.2.1 Interim Feature 2
#  files from the current directory to the $OMNIHOME/probes/$ARCH directory.

################################################################################
# Get platform
################################################################################
checkos()
{
    SYSTEM=`uname -s`
    OSVERSION=`uname -v`
    RELEASE=`uname -r`

    case $SYSTEM in
    SunOS)
        MAJOR=`echo $RELEASE | sed 's/\(.\).*/\1/'`
        if [ "4." = $MAJOR ]; then
            err "Unsupported version of SunOS"
        fi

        PROCESSOR=`uname -p`

        case $PROCESSOR in
        sparc)
            if [ ` echo $RELEASE | cut -f2 -d. ` -gt 5 ]; then
                # Post 2.5 may have special binaries
                SUFFIX=_2.6
            fi
            ARCH=solaris2
            ;;
        *)
            err "Unsupported processor for Solaris 2.x"
            ;;
        esac
        ;;
    AIX)
        case $OSVERSION in
        4)
            ARCH=aix4
            ;;
        5|6)
            ARCH=aix5
            ;;
        *)
            err "Unsupported version of AIX"
            ;;
        esac
        ;;
    HP-UX)
        RNUMBER=`echo $RELEASE | sed -e 's/.\.\(..\)\..*/\1/'`
        case $RNUMBER in
        10)
            ARCH=hpux10
            ;;
        11)
            ARCH=hpux11
            ;;
        *)
            err "Unsupported version of HP-UX"
            ;;
        esac
        ;;
    Linux)
        ARCH=`uname -m`
        RMAJOR=`echo $RELEASE | sed 's/\(.\).*/\1/'`
        case $ARCH in
        i*86|x86*)
            ARCH=linux"$RMAJOR"x86
            ;;
        s390*)
            ARCH=linux"$RMAJOR"s390
            ;;
        *)
            err "Unsupported processor for Linux"
            ;;
        esac
        ;;
    *)
        err "Unsupported platform"
        ;;
    esac
}

checkos;

if [ "$OMNIHOME" != "" ]
then
# cp -f zos_event.rules $OMNIHOME/probes/$ARCH
  cp -f zos_autooperator_event.rules $OMNIHOME/probes/$ARCH
  cp -f zos_mvpf_event.rules $OMNIHOME/probes/$ARCH
  echo "Files copied"
else
  echo "The environment variable OMNIHOME is not defined"
fi

